# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reports_public_report_response import ReportsPublicReportResponse

class TestReportsPublicReportResponse(unittest.TestCase):
    """ReportsPublicReportResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportsPublicReportResponse:
        """Test ReportsPublicReportResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportsPublicReportResponse`
        """
        model = ReportsPublicReportResponse()
        if include_optional:
            return ReportsPublicReportResponse(
                branding = neurograph.v1.models.reports/public_branding.reports.PublicBranding(
                    background_url = '', 
                    logo_url = '', 
                    primary_color = '', 
                    secondary_color = '', 
                    tertiary_color = '', ),
                call_to_action = '',
                client_name = '',
                embed_url = '',
                error = '',
                executive_summary = '',
                id = '',
                key_highlights = [
                    ''
                    ],
                key_stats = [
                    56
                    ],
                linked_concepts = [
                    ''
                    ],
                linked_themes = [
                    ''
                    ],
                main_insights = [
                    ''
                    ],
                name = '',
                og_image_url = '',
                report_type = '',
                report_type_label = '',
                thumbnail_url = '',
                ts_created = ''
            )
        else:
            return ReportsPublicReportResponse(
        )
        """

    def testReportsPublicReportResponse(self):
        """Test ReportsPublicReportResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.client_system_healthcheck_detail_response import ClientSystemHealthcheckDetailResponse

class TestClientSystemHealthcheckDetailResponse(unittest.TestCase):
    """ClientSystemHealthcheckDetailResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClientSystemHealthcheckDetailResponse:
        """Test ClientSystemHealthcheckDetailResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientSystemHealthcheckDetailResponse`
        """
        model = ClientSystemHealthcheckDetailResponse()
        if include_optional:
            return ClientSystemHealthcheckDetailResponse(
                data = neurograph.v1.models.client/system_healthcheck_snapshot.client.SystemHealthcheckSnapshot(
                    client_id = '', 
                    error_json = [
                        56
                        ], 
                    error_message = '', 
                    id = '', 
                    queries = [
                        neurograph.v1.models.client/system_healthcheck_query_result.client.SystemHealthcheckQueryResult(
                            check_key = '', 
                            display_name = '', 
                            error_message = '', 
                            query_id = '', 
                            query_version = 56, 
                            result_json = [
                                56
                                ], 
                            result_success = True, 
                            row_count = 56, 
                            status = '', 
                            ts_finished = '', 
                            ts_started = '', )
                        ], 
                    result_success = True, 
                    run_date = '', 
                    status = '', 
                    summary_json = [
                        56
                        ], 
                    ts_finished = '', 
                    ts_started = '', ),
                error = ''
            )
        else:
            return ClientSystemHealthcheckDetailResponse(
        )
        """

    def testClientSystemHealthcheckDetailResponse(self):
        """Test ClientSystemHealthcheckDetailResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_product_response import KnowledgeProductResponse

class TestKnowledgeProductResponse(unittest.TestCase):
    """KnowledgeProductResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeProductResponse:
        """Test KnowledgeProductResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeProductResponse`
        """
        model = KnowledgeProductResponse()
        if include_optional:
            return KnowledgeProductResponse(
                data = [
                    neurograph.v1.models.db/knowledge_product.db.KnowledgeProduct(
                        client_id = '', 
                        entity_id = '', 
                        handle = '', 
                        overview = '', 
                        product_hash = '', 
                        product_id = neurograph.v1.models.pgtype/int8.pgtype.Int8(
                            int64 = 56, 
                            valid = True, ), 
                        summary = '', 
                        title = '', 
                        type = '', )
                    ],
                error = '',
                query = neurograph.v1.models.knowledge/product_query.knowledge.ProductQuery(
                    client_id = '', 
                    handle = '', 
                    limit = 56, 
                    offset = 56, 
                    product_hash = '', 
                    product_id = 56, 
                    title = '', 
                    type = '', )
            )
        else:
            return KnowledgeProductResponse(
        )
        """

    def testKnowledgeProductResponse(self):
        """Test KnowledgeProductResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_customer_insights_response import ReportingCustomerInsightsResponse

class TestReportingCustomerInsightsResponse(unittest.TestCase):
    """ReportingCustomerInsightsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingCustomerInsightsResponse:
        """Test ReportingCustomerInsightsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingCustomerInsightsResponse`
        """
        model = ReportingCustomerInsightsResponse()
        if include_optional:
            return ReportingCustomerInsightsResponse(
                age_breakdown = [
                    neurograph.v1.models.reporting/age_breakdown_row.reporting.AgeBreakdownRow(
                        age_group = '', 
                        avg_aov = 1.337, 
                        avg_ltv = 1.337, 
                        conversion_rate = 1.337, 
                        customer_count = 56, 
                        total_orders = 56, )
                    ],
                cached = True,
                error = '',
                summary = neurograph.v1.models.reporting/summary_kpis.reporting.SummaryKPIs(
                    avg_ltv = 1.337, 
                    conversion_rate = 1.337, 
                    conversion_window_days = 56, 
                    predicted_pipeline_value = 1.337, 
                    total_visitors = 56, ),
                traffic_trend = [
                    neurograph.v1.models.reporting/traffic_trend_day.reporting.TrafficTrendDay(
                        date = '', 
                        new_customers = 56, 
                        returning_customers = 56, )
                    ],
                traffic_value_pipeline = [
                    neurograph.v1.models.reporting/traffic_pipeline_day.reporting.TrafficPipelineDay(
                        daily_total = neurograph.v1.models.reporting/daily_total.reporting.DailyTotal(
                            avg_value_per_visitor = 1.337, 
                            predicted_value = 1.337, 
                            visitors = 56, ), 
                        date = '', 
                        intent_bands = {
                            'key' : neurograph.v1.models.reporting/intent_band_data.reporting.IntentBandData(
                                avg_conversion_prob = 1.337, 
                                predicted_value = 1.337, 
                                visitor_count = 56, )
                            }, )
                    ]
            )
        else:
            return ReportingCustomerInsightsResponse(
        )
        """

    def testReportingCustomerInsightsResponse(self):
        """Test ReportingCustomerInsightsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from neurograph.v1.models.reports_linked_kpi import ReportsLinkedKPI
from neurograph.v1.models.reports_linked_query import ReportsLinkedQuery
from neurograph.v1.models.reports_recommendation import ReportsRecommendation
from typing import Optional, Set
from typing_extensions import Self

class ReportsReportArtifactCreateRequest(BaseModel):
    """
    ReportsReportArtifactCreateRequest
    """ # noqa: E501
    client_id: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    embed_url: Optional[StrictStr] = None
    executive_summary: Optional[StrictStr] = None
    key_stats: Optional[List[StrictInt]] = None
    linked_concepts: Optional[List[StrictStr]] = None
    linked_kpis: Optional[List[ReportsLinkedKPI]] = None
    linked_queries: Optional[List[ReportsLinkedQuery]] = None
    linked_themes: Optional[List[StrictStr]] = None
    linked_topics: Optional[List[StrictStr]] = None
    metadata: Optional[List[StrictInt]] = None
    name: StrictStr
    organization_id: Optional[StrictStr] = None
    pdf_url: Optional[StrictStr] = None
    presentation_url: StrictStr
    recommendations: Optional[List[ReportsRecommendation]] = None
    report_type: StrictStr
    thumbnail_url: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["client_id", "description", "embed_url", "executive_summary", "key_stats", "linked_concepts", "linked_kpis", "linked_queries", "linked_themes", "linked_topics", "metadata", "name", "organization_id", "pdf_url", "presentation_url", "recommendations", "report_type", "thumbnail_url"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ReportsReportArtifactCreateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in linked_kpis (list)
        _items = []
        if self.linked_kpis:
            for _item_linked_kpis in self.linked_kpis:
                if _item_linked_kpis:
                    _items.append(_item_linked_kpis.to_dict())
            _dict['linked_kpis'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in linked_queries (list)
        _items = []
        if self.linked_queries:
            for _item_linked_queries in self.linked_queries:
                if _item_linked_queries:
                    _items.append(_item_linked_queries.to_dict())
            _dict['linked_queries'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in recommendations (list)
        _items = []
        if self.recommendations:
            for _item_recommendations in self.recommendations:
                if _item_recommendations:
                    _items.append(_item_recommendations.to_dict())
            _dict['recommendations'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ReportsReportArtifactCreateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "client_id": obj.get("client_id"),
            "description": obj.get("description"),
            "embed_url": obj.get("embed_url"),
            "executive_summary": obj.get("executive_summary"),
            "key_stats": obj.get("key_stats"),
            "linked_concepts": obj.get("linked_concepts"),
            "linked_kpis": [ReportsLinkedKPI.from_dict(_item) for _item in obj["linked_kpis"]] if obj.get("linked_kpis") is not None else None,
            "linked_queries": [ReportsLinkedQuery.from_dict(_item) for _item in obj["linked_queries"]] if obj.get("linked_queries") is not None else None,
            "linked_themes": obj.get("linked_themes"),
            "linked_topics": obj.get("linked_topics"),
            "metadata": obj.get("metadata"),
            "name": obj.get("name"),
            "organization_id": obj.get("organization_id"),
            "pdf_url": obj.get("pdf_url"),
            "presentation_url": obj.get("presentation_url"),
            "recommendations": [ReportsRecommendation.from_dict(_item) for _item in obj["recommendations"]] if obj.get("recommendations") is not None else None,
            "report_type": obj.get("report_type"),
            "thumbnail_url": obj.get("thumbnail_url")
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_theme_preset_update_request import OrganizationsThemePresetUpdateRequest

class TestOrganizationsThemePresetUpdateRequest(unittest.TestCase):
    """OrganizationsThemePresetUpdateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsThemePresetUpdateRequest:
        """Test OrganizationsThemePresetUpdateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsThemePresetUpdateRequest`
        """
        model = OrganizationsThemePresetUpdateRequest()
        if include_optional:
            return OrganizationsThemePresetUpdateRequest(
                category = 'custom',
                color1 = '#FF6B35',
                color2 = '#F7931E',
                color3 = '#FFC857',
                color4 = '#2D5016',
                color5 = '#5C8A3D',
                description = 'An updated theme',
                id = 1,
                is_active = True,
                name = 'Updated Theme',
                preview_url = 'https://example.com/preview.png',
                primary_color = '#0066CC',
                secondary_color = '#00A3E0',
                tags = [custom, colorful],
                tertiary_color = '#7FDBFF'
            )
        else:
            return OrganizationsThemePresetUpdateRequest(
        )
        """

    def testOrganizationsThemePresetUpdateRequest(self):
        """Test OrganizationsThemePresetUpdateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_order_response import KnowledgeOrderResponse

class TestKnowledgeOrderResponse(unittest.TestCase):
    """KnowledgeOrderResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeOrderResponse:
        """Test KnowledgeOrderResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeOrderResponse`
        """
        model = KnowledgeOrderResponse()
        if include_optional:
            return KnowledgeOrderResponse(
                data = [
                    neurograph.v1.models.db/knowledge_order.db.KnowledgeOrder(
                        billing_address_hash = neurograph.v1.models.pgtype/text.pgtype.Text(
                            string = '', 
                            valid = True, ), 
                        billing_address_json = [
                            56
                            ], 
                        cancelled_at = neurograph.v1.models.pgtype/timestamp.pgtype.Timestamp(
                            infinity_modifier = 1, 
                            time = '', 
                            valid = True, ), 
                        channel = '', 
                        client_id = '', 
                        closed_at = neurograph.v1.models.pgtype/timestamp.pgtype.Timestamp(
                            time = '', 
                            valid = True, ), 
                        currency = '', 
                        customer_entity_id = neurograph.v1.models.pgtype/text.pgtype.Text(
                            string = '', 
                            valid = True, ), 
                        discount_amount = 1.337, 
                        email_at_order = , 
                        entity_id = '', 
                        ext_order_id = , 
                        ext_order_number = , 
                        ext_store_id = , 
                        financial_status = '', 
                        fulfillment_status = '', 
                        phone_at_order = , 
                        placed_at = , 
                        shipping_address_hash = , 
                        shipping_address_json = [
                            56
                            ], 
                        shipping_amount = 1.337, 
                        source_name = '', 
                        status = '', 
                        store_entity_id = , 
                        subtotal_amount = 1.337, 
                        tax_amount = 1.337, 
                        total_amount = 1.337, )
                    ],
                error = '',
                query = neurograph.v1.models.knowledge/order_query.knowledge.OrderQuery(
                    billing_address_hash = '', 
                    channel = '', 
                    client_id = '', 
                    currency = '', 
                    customer_entity_id = '', 
                    email_at_order = '', 
                    ext_order_id = '', 
                    ext_order_number = '', 
                    ext_store_id = '', 
                    financial_status = '', 
                    fulfillment_status = '', 
                    limit = 56, 
                    offset = 56, 
                    phone_at_order = '', 
                    placed_from = '', 
                    placed_to = '', 
                    shipping_address_hash = '', 
                    source_name = '', 
                    status = '', 
                    store_entity_id = '', 
                    total_max = '', 
                    total_min = '', )
            )
        else:
            return KnowledgeOrderResponse(
        )
        """

    def testKnowledgeOrderResponse(self):
        """Test KnowledgeOrderResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_portfolio_activity_response import ReportingPortfolioActivityResponse

class TestReportingPortfolioActivityResponse(unittest.TestCase):
    """ReportingPortfolioActivityResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingPortfolioActivityResponse:
        """Test ReportingPortfolioActivityResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingPortfolioActivityResponse`
        """
        model = ReportingPortfolioActivityResponse()
        if include_optional:
            return ReportingPortfolioActivityResponse(
                by_client = [
                    neurograph.v1.models.reporting/client_breakdown.reporting.ClientBreakdown(
                        client_uid = '', 
                        org_uid = '', 
                        purchases = 56, 
                        sessions = 56, )
                    ],
                by_org = [
                    neurograph.v1.models.reporting/org_breakdown.reporting.OrgBreakdown(
                        org_uid = '', 
                        purchases = 56, 
                        sessions = 56, )
                    ],
                cached = True,
                date_range = neurograph.v1.models.reporting/date_range.reporting.DateRange(
                    end_date = '', 
                    start_date = '', ),
                error = '',
                portfolio = neurograph.v1.models.reporting/portfolio_metrics.reporting.PortfolioMetrics(
                    daily_purchases = [
                        neurograph.v1.models.reporting/daily_summary.reporting.DailySummary(
                            count = 56, 
                            date = '', )
                        ], 
                    daily_sessions = [
                        neurograph.v1.models.reporting/daily_summary.reporting.DailySummary(
                            count = 56, 
                            date = '', )
                        ], 
                    total_purchases = 56, 
                    total_sessions = 56, ),
                query_time_ms = 56
            )
        else:
            return ReportingPortfolioActivityResponse(
        )
        """

    def testReportingPortfolioActivityResponse(self):
        """Test ReportingPortfolioActivityResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from neurograph.v1.models.reporting_scenario_market_concept import ReportingScenarioMarketConcept
from neurograph.v1.models.reporting_scenario_path import ReportingScenarioPath
from neurograph.v1.models.reporting_scenario_product import ReportingScenarioProduct
from typing import Optional, Set
from typing_extensions import Self

class ReportingBuyerScenario(BaseModel):
    """
    ReportingBuyerScenario
    """ # noqa: E501
    authored_boost: Optional[Union[StrictFloat, StrictInt]] = None
    blended_score: Optional[Union[StrictFloat, StrictInt]] = None
    cluster_boost: Optional[Union[StrictFloat, StrictInt]] = None
    cluster_ref_size: Optional[StrictInt] = None
    cluster_size: Optional[StrictInt] = None
    color: Optional[StrictStr] = None
    complexity: Optional[StrictStr] = None
    confidence: Optional[Union[StrictFloat, StrictInt]] = None
    description: Optional[StrictStr] = Field(default=None, description="Rich metadata (from resolved canonical entity's data column)")
    diversity_factor: Optional[Union[StrictFloat, StrictInt]] = None
    final_score: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="v7 Scores (adaptive blending + cluster boost + authored boost + signal gate)")
    graph_paths: Optional[StrictInt] = None
    graph_score: Optional[Union[StrictFloat, StrictInt]] = None
    graph_weight: Optional[Union[StrictFloat, StrictInt]] = None
    icon: Optional[StrictStr] = Field(default=None, description="UI helpers")
    intent: Optional[StrictStr] = None
    is_persona_authored: Optional[StrictBool] = Field(default=None, description="★ v7: Persona authorship diagnostics")
    key_concepts: Optional[List[StrictStr]] = None
    market_concepts: Optional[List[ReportingScenarioMarketConcept]] = Field(default=None, description="Ranked market concepts from knowledge graph")
    matched_products: Optional[StrictInt] = Field(default=None, description="Adaptive blend diagnostics")
    num_paths: Optional[StrictInt] = None
    persona_context: Optional[StrictStr] = None
    primary_category: Optional[StrictStr] = None
    product_diversity: Optional[Union[StrictFloat, StrictInt]] = None
    product_paths: Optional[StrictInt] = None
    product_score: Optional[Union[StrictFloat, StrictInt]] = None
    product_signal_count: Optional[StrictInt] = Field(default=None, description="Signal diagnostics")
    product_signal_gate: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="★ v7: Product signal gate (purchase-evidence multiplier)")
    purchase_likelihood: Optional[Union[StrictFloat, StrictInt]] = None
    relevance_pct: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Normalised relevance score (0-100, top scenario = 100)")
    scenario_name: Optional[StrictStr] = None
    scenario_resolved_id: Optional[StrictStr] = Field(default=None, description="Identity")
    scenario_type: Optional[StrictStr] = None
    scenario_variants: Optional[List[StrictStr]] = None
    shortest_path: Optional[StrictInt] = None
    source_persona_id: Optional[StrictStr] = None
    tags: Optional[List[StrictStr]] = None
    timeline: Optional[StrictStr] = None
    top_paths: Optional[List[ReportingScenarioPath]] = Field(default=None, description="Explainability")
    top_products: Optional[List[ReportingScenarioProduct]] = None
    trigger_event: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["authored_boost", "blended_score", "cluster_boost", "cluster_ref_size", "cluster_size", "color", "complexity", "confidence", "description", "diversity_factor", "final_score", "graph_paths", "graph_score", "graph_weight", "icon", "intent", "is_persona_authored", "key_concepts", "market_concepts", "matched_products", "num_paths", "persona_context", "primary_category", "product_diversity", "product_paths", "product_score", "product_signal_count", "product_signal_gate", "purchase_likelihood", "relevance_pct", "scenario_name", "scenario_resolved_id", "scenario_type", "scenario_variants", "shortest_path", "source_persona_id", "tags", "timeline", "top_paths", "top_products", "trigger_event"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ReportingBuyerScenario from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in market_concepts (list)
        _items = []
        if self.market_concepts:
            for _item_market_concepts in self.market_concepts:
                if _item_market_concepts:
                    _items.append(_item_market_concepts.to_dict())
            _dict['market_concepts'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_paths (list)
        _items = []
        if self.top_paths:
            for _item_top_paths in self.top_paths:
                if _item_top_paths:
                    _items.append(_item_top_paths.to_dict())
            _dict['top_paths'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_products (list)
        _items = []
        if self.top_products:
            for _item_top_products in self.top_products:
                if _item_top_products:
                    _items.append(_item_top_products.to_dict())
            _dict['top_products'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ReportingBuyerScenario from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "authored_boost": obj.get("authored_boost"),
            "blended_score": obj.get("blended_score"),
            "cluster_boost": obj.get("cluster_boost"),
            "cluster_ref_size": obj.get("cluster_ref_size"),
            "cluster_size": obj.get("cluster_size"),
            "color": obj.get("color"),
            "complexity": obj.get("complexity"),
            "confidence": obj.get("confidence"),
            "description": obj.get("description"),
            "diversity_factor": obj.get("diversity_factor"),
            "final_score": obj.get("final_score"),
            "graph_paths": obj.get("graph_paths"),
            "graph_score": obj.get("graph_score"),
            "graph_weight": obj.get("graph_weight"),
            "icon": obj.get("icon"),
            "intent": obj.get("intent"),
            "is_persona_authored": obj.get("is_persona_authored"),
            "key_concepts": obj.get("key_concepts"),
            "market_concepts": [ReportingScenarioMarketConcept.from_dict(_item) for _item in obj["market_concepts"]] if obj.get("market_concepts") is not None else None,
            "matched_products": obj.get("matched_products"),
            "num_paths": obj.get("num_paths"),
            "persona_context": obj.get("persona_context"),
            "primary_category": obj.get("primary_category"),
            "product_diversity": obj.get("product_diversity"),
            "product_paths": obj.get("product_paths"),
            "product_score": obj.get("product_score"),
            "product_signal_count": obj.get("product_signal_count"),
            "product_signal_gate": obj.get("product_signal_gate"),
            "purchase_likelihood": obj.get("purchase_likelihood"),
            "relevance_pct": obj.get("relevance_pct"),
            "scenario_name": obj.get("scenario_name"),
            "scenario_resolved_id": obj.get("scenario_resolved_id"),
            "scenario_type": obj.get("scenario_type"),
            "scenario_variants": obj.get("scenario_variants"),
            "shortest_path": obj.get("shortest_path"),
            "source_persona_id": obj.get("source_persona_id"),
            "tags": obj.get("tags"),
            "timeline": obj.get("timeline"),
            "top_paths": [ReportingScenarioPath.from_dict(_item) for _item in obj["top_paths"]] if obj.get("top_paths") is not None else None,
            "top_products": [ReportingScenarioProduct.from_dict(_item) for _item in obj["top_products"]] if obj.get("top_products") is not None else None,
            "trigger_event": obj.get("trigger_event")
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.client_upsert_response import ClientUpsertResponse

class TestClientUpsertResponse(unittest.TestCase):
    """ClientUpsertResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClientUpsertResponse:
        """Test ClientUpsertResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientUpsertResponse`
        """
        model = ClientUpsertResponse()
        if include_optional:
            return ClientUpsertResponse(
                error = '',
                id = '',
                is_active = True,
                name = '',
                org_id = '',
                pixel_snippets = [
                    neurograph.v1.models.db/pixel_snippet.db.PixelSnippet(
                        id = 56, 
                        name = '', 
                        snippet = '', )
                    ],
                ts_created = 56,
                ts_updated = 56,
                uid = '',
                urls = [
                    neurograph.v1.models.db/client_url.db.ClientUrl(
                        client_id = 'cli_12345', 
                        customer_environment = '', 
                        id = 56, 
                        is_active = True, 
                        url = 'example.com', )
                    ]
            )
        else:
            return ClientUpsertResponse(
        )
        """

    def testClientUpsertResponse(self):
        """Test ClientUpsertResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_traffic_pipeline_day import ReportingTrafficPipelineDay

class TestReportingTrafficPipelineDay(unittest.TestCase):
    """ReportingTrafficPipelineDay unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingTrafficPipelineDay:
        """Test ReportingTrafficPipelineDay
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingTrafficPipelineDay`
        """
        model = ReportingTrafficPipelineDay()
        if include_optional:
            return ReportingTrafficPipelineDay(
                daily_total = neurograph.v1.models.reporting/daily_total.reporting.DailyTotal(
                    avg_value_per_visitor = 1.337, 
                    predicted_value = 1.337, 
                    visitors = 56, ),
                var_date = '',
                intent_bands = {
                    'key' : neurograph.v1.models.reporting/intent_band_data.reporting.IntentBandData(
                        avg_conversion_prob = 1.337, 
                        predicted_value = 1.337, 
                        visitor_count = 56, )
                    }
            )
        else:
            return ReportingTrafficPipelineDay(
        )
        """

    def testReportingTrafficPipelineDay(self):
        """Test ReportingTrafficPipelineDay"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_gamma_theme_settings import OrganizationsGammaThemeSettings

class TestOrganizationsGammaThemeSettings(unittest.TestCase):
    """OrganizationsGammaThemeSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsGammaThemeSettings:
        """Test OrganizationsGammaThemeSettings
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsGammaThemeSettings`
        """
        model = OrganizationsGammaThemeSettings()
        if include_optional:
            return OrganizationsGammaThemeSettings(
                colors = neurograph.v1.models.organizations/gamma_color_settings.organizations.GammaColorSettings(
                    adjust_for_accessibility = True, 
                    body_color = '', 
                    card_background_color = '', 
                    heading_color = '', 
                    page_background = '', 
                    page_background_color = '', 
                    primary_accent_color = '', 
                    secondary_accent_colors = [
                        ''
                        ], ),
                design = neurograph.v1.models.organizations/gamma_design_settings.organizations.GammaDesignSettings(
                    blocks = neurograph.v1.models.blocks.blocks(), 
                    buttons = neurograph.v1.models.buttons.buttons(), 
                    cards = neurograph.v1.models.cards.cards(), ),
                fonts = neurograph.v1.models.organizations/gamma_font_settings.organizations.GammaFontSettings(
                    body_base_size = 56, 
                    body_color = '', 
                    body_font = '', 
                    body_letter_spacing = 1.337, 
                    body_line_height = 1.337, 
                    body_weight = '', 
                    heading_color = '', 
                    heading_font = '', 
                    heading_letter_spacing = 1.337, 
                    heading_line_height = 1.337, 
                    heading_weight = '', ),
                reasoning = ''
            )
        else:
            return OrganizationsGammaThemeSettings(
        )
        """

    def testOrganizationsGammaThemeSettings(self):
        """Test OrganizationsGammaThemeSettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.client_urls_response import ClientUrlsResponse

class TestClientUrlsResponse(unittest.TestCase):
    """ClientUrlsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClientUrlsResponse:
        """Test ClientUrlsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientUrlsResponse`
        """
        model = ClientUrlsResponse()
        if include_optional:
            return ClientUrlsResponse(
                data = [
                    neurograph.v1.models.client/url_row.client.UrlRow(
                        client_id = 'cli_12345', 
                        customer_environment = '', 
                        id = 56, 
                        is_active = True, 
                        probes = [
                            neurograph.v1.models.client/probe.client.Probe(
                                error = '', 
                                final_url = '', 
                                has_snapshot = True, 
                                id = '', 
                                is_ok = True, 
                                method = '', 
                                requested_url = '', 
                                response_ms = 56, 
                                status_code = 56, 
                                ts_checked = 56, )
                            ], 
                        ts_created = 56, 
                        url = 'example.com', )
                    ],
                error = '',
                query_client_id = '',
                total_rows = 56
            )
        else:
            return ClientUrlsResponse(
        )
        """

    def testClientUrlsResponse(self):
        """Test ClientUrlsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_brand_detail_response import OrganizationsBrandDetailResponse

class TestOrganizationsBrandDetailResponse(unittest.TestCase):
    """OrganizationsBrandDetailResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsBrandDetailResponse:
        """Test OrganizationsBrandDetailResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsBrandDetailResponse`
        """
        model = OrganizationsBrandDetailResponse()
        if include_optional:
            return OrganizationsBrandDetailResponse(
                accessibility_level = '',
                background_img_url = '',
                color1 = '',
                color2 = '',
                color3 = '',
                color4 = '',
                color5 = '',
                components = neurograph.v1.models.organizations/component_config.organizations.ComponentConfig(
                    border_radius = '', 
                    button_style = '', 
                    card_style = '', ),
                dark_mode_enabled = True,
                error = '',
                generation_metadata = neurograph.v1.models.organizations/generation_metadata.organizations.GenerationMetadata(
                    generated_at = '', 
                    model = '', 
                    parameters = { }, 
                    prompt = '', ),
                is_ai_generated = True,
                logo_img_url = '',
                org_guid = 'org_123',
                primary_color = '',
                secondary_color = '',
                spacing = neurograph.v1.models.organizations/spacing_config.organizations.SpacingConfig(
                    base_unit = 56, 
                    scale = '', ),
                tertiary_color = '',
                typography = neurograph.v1.models.organizations/typography_config.organizations.TypographyConfig(
                    body_size = '', 
                    font_family = '', 
                    heading_scale = 1.337, ),
                version = 56
            )
        else:
            return OrganizationsBrandDetailResponse(
        )
        """

    def testOrganizationsBrandDetailResponse(self):
        """Test OrganizationsBrandDetailResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_test_accessibility_response import OrganizationsTestAccessibilityResponse

class TestOrganizationsTestAccessibilityResponse(unittest.TestCase):
    """OrganizationsTestAccessibilityResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsTestAccessibilityResponse:
        """Test OrganizationsTestAccessibilityResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsTestAccessibilityResponse`
        """
        model = OrganizationsTestAccessibilityResponse()
        if include_optional:
            return OrganizationsTestAccessibilityResponse(
                color_pair_results = [
                    neurograph.v1.models.utils/color_pair_result.utils.ColorPairResult(
                        background_color = '', 
                        contrast_ratio = 1.337, 
                        foreground_color = '', 
                        passes_large_aa = True, 
                        passes_large_aaa = True, 
                        passes_normal_aa = True, 
                        passes_normal_aaa = True, 
                        passes_ui_aa = True, 
                        recommendation = '', )
                    ],
                error = '',
                issues = [
                    ''
                    ],
                level = '',
                passes_aa = True,
                passes_aaa = True,
                recommendations = [
                    ''
                    ],
                score = 56
            )
        else:
            return OrganizationsTestAccessibilityResponse(
        )
        """

    def testOrganizationsTestAccessibilityResponse(self):
        """Test OrganizationsTestAccessibilityResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_category_spend_data import ReportingCategorySpendData

class TestReportingCategorySpendData(unittest.TestCase):
    """ReportingCategorySpendData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingCategorySpendData:
        """Test ReportingCategorySpendData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingCategorySpendData`
        """
        model = ReportingCategorySpendData()
        if include_optional:
            return ReportingCategorySpendData(
                categories = [
                    ''
                    ],
                data = [
                    neurograph.v1.models.reporting/category_spend_week.reporting.CategorySpendWeek(
                        spend = {
                            'key' : 1.337
                            }, 
                        week = '', )
                    ],
                period_comparison = neurograph.v1.models.reporting/period_comparison.reporting.PeriodComparison(
                    change_percentage = 1.337, 
                    current_period_spend = 1.337, 
                    previous_period_spend = 1.337, 
                    trend = '', ),
                total_spend = 1.337,
                weeks = [
                    ''
                    ]
            )
        else:
            return ReportingCategorySpendData(
        )
        """

    def testReportingCategorySpendData(self):
        """Test ReportingCategorySpendData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reports_recommendation import ReportsRecommendation

class TestReportsRecommendation(unittest.TestCase):
    """ReportsRecommendation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportsRecommendation:
        """Test ReportsRecommendation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportsRecommendation`
        """
        model = ReportsRecommendation()
        if include_optional:
            return ReportsRecommendation(
                action_url = '/campaigns/create?segment=a',
                category = 'engagement',
                id = '',
                priority = 'high',
                title = 'Increase email frequency for Segment A'
            )
        else:
            return ReportsRecommendation(
        )
        """

    def testReportsRecommendation(self):
        """Test ReportsRecommendation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.client_system_healthcheck_snapshot import ClientSystemHealthcheckSnapshot

class TestClientSystemHealthcheckSnapshot(unittest.TestCase):
    """ClientSystemHealthcheckSnapshot unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClientSystemHealthcheckSnapshot:
        """Test ClientSystemHealthcheckSnapshot
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientSystemHealthcheckSnapshot`
        """
        model = ClientSystemHealthcheckSnapshot()
        if include_optional:
            return ClientSystemHealthcheckSnapshot(
                client_id = '',
                error_json = [
                    56
                    ],
                error_message = '',
                id = '',
                queries = [
                    neurograph.v1.models.client/system_healthcheck_query_result.client.SystemHealthcheckQueryResult(
                        check_key = '', 
                        display_name = '', 
                        error_message = '', 
                        query_id = '', 
                        query_version = 56, 
                        result_json = [
                            56
                            ], 
                        result_success = True, 
                        row_count = 56, 
                        status = '', 
                        ts_finished = '', 
                        ts_started = '', )
                    ],
                result_success = True,
                run_date = '',
                status = '',
                summary_json = [
                    56
                    ],
                ts_finished = '',
                ts_started = ''
            )
        else:
            return ClientSystemHealthcheckSnapshot(
        )
        """

    def testClientSystemHealthcheckSnapshot(self):
        """Test ClientSystemHealthcheckSnapshot"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr
from typing import Optional
from typing_extensions import Annotated
from neurograph.v1.models.lookup_language_response import LookupLanguageResponse
from neurograph.v1.models.lookup_lookup_environments_response import LookupLookupEnvironmentsResponse
from neurograph.v1.models.lookup_roles_response import LookupRolesResponse
from neurograph.v1.models.lookup_state_response import LookupStateResponse
from neurograph.v1.models.lookup_states_response import LookupStatesResponse
from neurograph.v1.models.lookup_sync_snippets_response import LookupSyncSnippetsResponse
from neurograph.v1.models.lookup_uids_response import LookupUidsResponse

from neurograph.v1.api_client import ApiClient, RequestSerialized
from neurograph.v1.api_response import ApiResponse
from neurograph.v1.rest import RESTResponseType


class LookupApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def api_v1_lookup_environments_get(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> LookupLookupEnvironmentsResponse:
        """Get Environments

        Retrieve Environments that are possible for Client's URLs

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_lookup_environments_get_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LookupLookupEnvironmentsResponse",
            '503': "LookupLookupEnvironmentsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_lookup_environments_get_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[LookupLookupEnvironmentsResponse]:
        """Get Environments

        Retrieve Environments that are possible for Client's URLs

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_lookup_environments_get_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LookupLookupEnvironmentsResponse",
            '503': "LookupLookupEnvironmentsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_lookup_environments_get_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Environments

        Retrieve Environments that are possible for Client's URLs

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_lookup_environments_get_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LookupLookupEnvironmentsResponse",
            '503': "LookupLookupEnvironmentsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_lookup_environments_get_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/lookup/environments',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_lookup_languages_get(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> LookupLanguageResponse:
        """Lookup Supported Languages

        Lookup Supported Languages

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_lookup_languages_get_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LookupLanguageResponse",
            '503': "LookupLanguageResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_lookup_languages_get_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[LookupLanguageResponse]:
        """Lookup Supported Languages

        Lookup Supported Languages

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_lookup_languages_get_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LookupLanguageResponse",
            '503': "LookupLanguageResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_lookup_languages_get_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Lookup Supported Languages

        Lookup Supported Languages

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_lookup_languages_get_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LookupLanguageResponse",
            '503': "LookupLanguageResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_lookup_languages_get_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/lookup/languages',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_lookup_snippets_sync_post(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> LookupSyncSnippetsResponse:
        """Sync client snippets

        Generate missing client pixel snippets.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_lookup_snippets_sync_post_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LookupSyncSnippetsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_lookup_snippets_sync_post_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[LookupSyncSnippetsResponse]:
        """Sync client snippets

        Generate missing client pixel snippets.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_lookup_snippets_sync_post_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LookupSyncSnippetsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_lookup_snippets_sync_post_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Sync client snippets

        Generate missing client pixel snippets.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_lookup_snippets_sync_post_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LookupSyncSnippetsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_lookup_snippets_sync_post_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v1/lookup/snippets/sync',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_lookup_states_code_get(
        self,
        code: Annotated[StrictStr, Field(description="State two letter code")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> LookupStateResponse:
        """Get US State by Code

        Retrieve a US State by its code

        :param code: State two letter code (required)
        :type code: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_lookup_states_code_get_serialize(
            code=code,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LookupStateResponse",
            '503': "LookupStateResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_lookup_states_code_get_with_http_info(
        self,
        code: Annotated[StrictStr, Field(description="State two letter code")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[LookupStateResponse]:
        """Get US State by Code

        Retrieve a US State by its code

        :param code: State two letter code (required)
        :type code: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_lookup_states_code_get_serialize(
            code=code,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LookupStateResponse",
            '503': "LookupStateResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_lookup_states_code_get_without_preload_content(
        self,
        code: Annotated[StrictStr, Field(description="State two letter code")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get US State by Code

        Retrieve a US State by its code

        :param code: State two letter code (required)
        :type code: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_lookup_states_code_get_serialize(
            code=code,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LookupStateResponse",
            '503': "LookupStateResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_lookup_states_code_get_serialize(
        self,
        code,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if code is not None:
            _path_params['code'] = code
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/lookup/states/{code}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_lookup_states_get(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> LookupStatesResponse:
        """Get US States

        Retrieve US States

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_lookup_states_get_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LookupStatesResponse",
            '503': "LookupStatesResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_lookup_states_get_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[LookupStatesResponse]:
        """Get US States

        Retrieve US States

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_lookup_states_get_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LookupStatesResponse",
            '503': "LookupStatesResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_lookup_states_get_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get US States

        Retrieve US States

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_lookup_states_get_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LookupStatesResponse",
            '503': "LookupStatesResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_lookup_states_get_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/lookup/states/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_lookup_uids_get(
        self,
        only_active: Annotated[Optional[StrictStr], Field(description="Filter to return only activ orgs and clients")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> LookupUidsResponse:
        """Get legacy uids for matching knowledge data

        Get an array of uids for matching Clients and Orgs with legacy data

        :param only_active: Filter to return only activ orgs and clients
        :type only_active: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_lookup_uids_get_serialize(
            only_active=only_active,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LookupUidsResponse",
            '400': "LookupUidsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_lookup_uids_get_with_http_info(
        self,
        only_active: Annotated[Optional[StrictStr], Field(description="Filter to return only activ orgs and clients")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[LookupUidsResponse]:
        """Get legacy uids for matching knowledge data

        Get an array of uids for matching Clients and Orgs with legacy data

        :param only_active: Filter to return only activ orgs and clients
        :type only_active: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_lookup_uids_get_serialize(
            only_active=only_active,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LookupUidsResponse",
            '400': "LookupUidsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_lookup_uids_get_without_preload_content(
        self,
        only_active: Annotated[Optional[StrictStr], Field(description="Filter to return only activ orgs and clients")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get legacy uids for matching knowledge data

        Get an array of uids for matching Clients and Orgs with legacy data

        :param only_active: Filter to return only activ orgs and clients
        :type only_active: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_lookup_uids_get_serialize(
            only_active=only_active,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LookupUidsResponse",
            '400': "LookupUidsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_lookup_uids_get_serialize(
        self,
        only_active,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if only_active is not None:
            
            _query_params.append(('onlyActive', only_active))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/lookup/uids',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_lookup_user_roles_get(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> LookupRolesResponse:
        """Get Possible User Roles

        Retrieve possible user roles

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_lookup_user_roles_get_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LookupRolesResponse",
            '503': "LookupRolesResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_lookup_user_roles_get_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[LookupRolesResponse]:
        """Get Possible User Roles

        Retrieve possible user roles

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_lookup_user_roles_get_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LookupRolesResponse",
            '503': "LookupRolesResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_lookup_user_roles_get_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Possible User Roles

        Retrieve possible user roles

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_lookup_user_roles_get_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LookupRolesResponse",
            '503': "LookupRolesResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_lookup_user_roles_get_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/lookup/user-roles/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from neurograph.v1.models.pgtype_bool import PgtypeBool
from neurograph.v1.models.pgtype_int4 import PgtypeInt4
from neurograph.v1.models.pgtype_text import PgtypeText
from neurograph.v1.models.pgtype_timestamptz import PgtypeTimestamptz
from typing import Optional, Set
from typing_extensions import Self

class DbAccountOrganizationBrand(BaseModel):
    """
    DbAccountOrganizationBrand
    """ # noqa: E501
    accessibility_level: Optional[PgtypeText] = None
    background_img_url: Optional[StrictStr] = None
    color1: Optional[StrictStr] = None
    color2: Optional[StrictStr] = None
    color3: Optional[StrictStr] = None
    color4: Optional[StrictStr] = None
    color5: Optional[StrictStr] = None
    component_config: Optional[List[StrictInt]] = None
    dark_mode_enabled: Optional[PgtypeBool] = None
    generation_metadata: Optional[List[StrictInt]] = None
    id: Optional[StrictInt] = None
    is_ai_generated: Optional[PgtypeBool] = None
    logo_img_url: Optional[StrictStr] = None
    org_id: Optional[StrictStr] = None
    preset_applied_at: Optional[PgtypeTimestamptz] = Field(default=None, description="Timestamp when preset was last applied")
    preset_customized: Optional[PgtypeBool] = Field(default=None, description="Whether the preset has been customized after application")
    preset_id: Optional[PgtypeText] = Field(default=None, description="ID of the theme preset applied to this branding")
    preset_name: Optional[PgtypeText] = Field(default=None, description="Name of the theme preset for display purposes")
    primary_color: Optional[StrictStr] = None
    secondary_color: Optional[StrictStr] = None
    spacing_config: Optional[List[StrictInt]] = None
    tertiary_color: Optional[StrictStr] = None
    typography_config: Optional[List[StrictInt]] = None
    version: Optional[PgtypeInt4] = None
    __properties: ClassVar[List[str]] = ["accessibility_level", "background_img_url", "color1", "color2", "color3", "color4", "color5", "component_config", "dark_mode_enabled", "generation_metadata", "id", "is_ai_generated", "logo_img_url", "org_id", "preset_applied_at", "preset_customized", "preset_id", "preset_name", "primary_color", "secondary_color", "spacing_config", "tertiary_color", "typography_config", "version"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DbAccountOrganizationBrand from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of accessibility_level
        if self.accessibility_level:
            _dict['accessibility_level'] = self.accessibility_level.to_dict()
        # override the default output from pydantic by calling `to_dict()` of dark_mode_enabled
        if self.dark_mode_enabled:
            _dict['dark_mode_enabled'] = self.dark_mode_enabled.to_dict()
        # override the default output from pydantic by calling `to_dict()` of is_ai_generated
        if self.is_ai_generated:
            _dict['is_ai_generated'] = self.is_ai_generated.to_dict()
        # override the default output from pydantic by calling `to_dict()` of preset_applied_at
        if self.preset_applied_at:
            _dict['preset_applied_at'] = self.preset_applied_at.to_dict()
        # override the default output from pydantic by calling `to_dict()` of preset_customized
        if self.preset_customized:
            _dict['preset_customized'] = self.preset_customized.to_dict()
        # override the default output from pydantic by calling `to_dict()` of preset_id
        if self.preset_id:
            _dict['preset_id'] = self.preset_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of preset_name
        if self.preset_name:
            _dict['preset_name'] = self.preset_name.to_dict()
        # override the default output from pydantic by calling `to_dict()` of version
        if self.version:
            _dict['version'] = self.version.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DbAccountOrganizationBrand from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "accessibility_level": PgtypeText.from_dict(obj["accessibility_level"]) if obj.get("accessibility_level") is not None else None,
            "background_img_url": obj.get("background_img_url"),
            "color1": obj.get("color1"),
            "color2": obj.get("color2"),
            "color3": obj.get("color3"),
            "color4": obj.get("color4"),
            "color5": obj.get("color5"),
            "component_config": obj.get("component_config"),
            "dark_mode_enabled": PgtypeBool.from_dict(obj["dark_mode_enabled"]) if obj.get("dark_mode_enabled") is not None else None,
            "generation_metadata": obj.get("generation_metadata"),
            "id": obj.get("id"),
            "is_ai_generated": PgtypeBool.from_dict(obj["is_ai_generated"]) if obj.get("is_ai_generated") is not None else None,
            "logo_img_url": obj.get("logo_img_url"),
            "org_id": obj.get("org_id"),
            "preset_applied_at": PgtypeTimestamptz.from_dict(obj["preset_applied_at"]) if obj.get("preset_applied_at") is not None else None,
            "preset_customized": PgtypeBool.from_dict(obj["preset_customized"]) if obj.get("preset_customized") is not None else None,
            "preset_id": PgtypeText.from_dict(obj["preset_id"]) if obj.get("preset_id") is not None else None,
            "preset_name": PgtypeText.from_dict(obj["preset_name"]) if obj.get("preset_name") is not None else None,
            "primary_color": obj.get("primary_color"),
            "secondary_color": obj.get("secondary_color"),
            "spacing_config": obj.get("spacing_config"),
            "tertiary_color": obj.get("tertiary_color"),
            "typography_config": obj.get("typography_config"),
            "version": PgtypeInt4.from_dict(obj["version"]) if obj.get("version") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_brand_generation_response import OrganizationsBrandGenerationResponse

class TestOrganizationsBrandGenerationResponse(unittest.TestCase):
    """OrganizationsBrandGenerationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsBrandGenerationResponse:
        """Test OrganizationsBrandGenerationResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsBrandGenerationResponse`
        """
        model = OrganizationsBrandGenerationResponse()
        if include_optional:
            return OrganizationsBrandGenerationResponse(
                brand = neurograph.v1.models.openai/generated_brand.openai.GeneratedBrand(
                    accessibility = neurograph.v1.models.openai/accessibility_info.openai.AccessibilityInfo(
                        contrast_ratios = {
                            'key' : 1.337
                            }, 
                        notes = '', 
                        passes = '', ), 
                    analysis = neurograph.v1.models.openai/brand_analysis.openai.BrandAnalysis(
                        design_style = '', 
                        industry_fit = '', 
                        personality = [
                            ''
                            ], ), 
                    colors = neurograph.v1.models.openai/brand_colors.openai.BrandColors(
                        color1 = '', 
                        color2 = '', 
                        color3 = '', 
                        color4 = '', 
                        color5 = '', 
                        primary_color = '', 
                        secondary_color = '', 
                        tertiary_color = '', ), 
                    reasoning = '', ),
                error = '',
                success = True
            )
        else:
            return OrganizationsBrandGenerationResponse(
        )
        """

    def testOrganizationsBrandGenerationResponse(self):
        """Test OrganizationsBrandGenerationResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_customer_response import KnowledgeCustomerResponse

class TestKnowledgeCustomerResponse(unittest.TestCase):
    """KnowledgeCustomerResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeCustomerResponse:
        """Test KnowledgeCustomerResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeCustomerResponse`
        """
        model = KnowledgeCustomerResponse()
        if include_optional:
            return KnowledgeCustomerResponse(
                data = [
                    neurograph.v1.models.db/knowledge_customer.db.KnowledgeCustomer(
                        client_id = '', 
                        email = '', 
                        entity_id = '', 
                        first_name = '', 
                        last_name = '', 
                        phone = '', )
                    ],
                error = '',
                query = neurograph.v1.models.knowledge/customer_query.knowledge.CustomerQuery(
                    client_id = '', 
                    email = '', 
                    first_name = '', 
                    last_name = '', 
                    limit = 56, 
                    offset = 56, 
                    phone = '', )
            )
        else:
            return KnowledgeCustomerResponse(
        )
        """

    def testKnowledgeCustomerResponse(self):
        """Test KnowledgeCustomerResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
